@@ -1,4 +1,4 @@
-// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// © 2016 and later: Unicode, Inc. and others.
 // License & terms of use: http://www.unicode.org/copyright.html
 /********************************************************************
  * COPYRIGHT: 
@@ -6,7 +6,7 @@
  * others. All Rights Reserved.
  ********************************************************************/
 /*   file name:  strtest.h
-*   encoding:   US-ASCII
+*   encoding:   UTF-8
 *   tab size:   8 (not used)
 *   indentation:4
 *
@@ -39,15 +39,25 @@ private:
     void Test_U_STRING();
     void Test_UNICODE_STRING();
     void Test_UNICODE_STRING_SIMPLE();
+    void TestUpperOrdinal();
+    void TestLowerOrdinal();
     void Test_UTF8_COUNT_TRAIL_BYTES();
     void TestStringPiece();
+    void TestStringPieceFind();
     void TestStringPieceComparisons();
+    void TestStringPieceOther();
+#ifdef U_HAVE_STRING_VIEW
+    void TestStringPieceStringView();
+#endif
+    void TestStringPieceU8();
     void TestByteSink();
     void TestCheckedArrayByteSink();
     void TestStringByteSink();
+    void TestStringByteSinkAppendU8();
     void TestSTLCompatibility();
     void TestCharString();
     void TestCStr();
+    void TestCharStrAppendNumber();
     void Testctou();
 };
 
